# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _medmesh
else:
    import _medmesh

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medmesh_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medmesh.delete_SwigPyIterator_medmesh_module

    def value(self):
        return _medmesh.SwigPyIterator_medmesh_module_value(self)

    def incr(self, n=1):
        return _medmesh.SwigPyIterator_medmesh_module_incr(self, n)

    def decr(self, n=1):
        return _medmesh.SwigPyIterator_medmesh_module_decr(self, n)

    def distance(self, x):
        return _medmesh.SwigPyIterator_medmesh_module_distance(self, x)

    def equal(self, x):
        return _medmesh.SwigPyIterator_medmesh_module_equal(self, x)

    def copy(self):
        return _medmesh.SwigPyIterator_medmesh_module_copy(self)

    def next(self):
        return _medmesh.SwigPyIterator_medmesh_module_next(self)

    def __next__(self):
        return _medmesh.SwigPyIterator_medmesh_module___next__(self)

    def previous(self):
        return _medmesh.SwigPyIterator_medmesh_module_previous(self)

    def advance(self, n):
        return _medmesh.SwigPyIterator_medmesh_module_advance(self, n)

    def __eq__(self, x):
        return _medmesh.SwigPyIterator_medmesh_module___eq__(self, x)

    def __ne__(self, x):
        return _medmesh.SwigPyIterator_medmesh_module___ne__(self, x)

    def __iadd__(self, n):
        return _medmesh.SwigPyIterator_medmesh_module___iadd__(self, n)

    def __isub__(self, n):
        return _medmesh.SwigPyIterator_medmesh_module___isub__(self, n)

    def __add__(self, n):
        return _medmesh.SwigPyIterator_medmesh_module___add__(self, n)

    def __sub__(self, *args):
        return _medmesh.SwigPyIterator_medmesh_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medmesh_module in _medmesh:
_medmesh.SwigPyIterator_medmesh_module_swigregister(SwigPyIterator_medmesh_module)
HAVE_CC_C99 = _medmesh.HAVE_CC_C99
HAVE_CUSERID = _medmesh.HAVE_CUSERID
HAVE_DLFCN_H = _medmesh.HAVE_DLFCN_H
HAVE_FTIME = _medmesh.HAVE_FTIME
HAVE_GETEUID = _medmesh.HAVE_GETEUID
HAVE_GETPWUID = _medmesh.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medmesh.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medmesh.HAVE_H5PUBLIC_H
HAVE_INT64 = _medmesh.HAVE_INT64
HAVE_INTTYPES_H = _medmesh.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medmesh.HAVE_MALLOC_H
HAVE_PWD_H = _medmesh.HAVE_PWD_H
HAVE_STDBOOL_H = _medmesh.HAVE_STDBOOL_H
HAVE_STDINT_H = _medmesh.HAVE_STDINT_H
HAVE_STDIO_H = _medmesh.HAVE_STDIO_H
HAVE_STDLIB_H = _medmesh.HAVE_STDLIB_H
HAVE_STRINGS_H = _medmesh.HAVE_STRINGS_H
HAVE_STRING_H = _medmesh.HAVE_STRING_H
HAVE_SYS_STAT_H = _medmesh.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medmesh.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medmesh.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medmesh.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medmesh.HAVE_UNISTD_H
HAVE__BOOL = _medmesh.HAVE__BOOL
MED_CHECK_23FORMAT = _medmesh.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medmesh.MED_HAVE_FORTRAN
MESGERR = _medmesh.MESGERR
PACKAGE = _medmesh.PACKAGE
PACKAGE_BUGREPORT = _medmesh.PACKAGE_BUGREPORT
PACKAGE_NAME = _medmesh.PACKAGE_NAME
PACKAGE_STRING = _medmesh.PACKAGE_STRING
PACKAGE_URL = _medmesh.PACKAGE_URL
PACKAGE_VERSION = _medmesh.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medmesh.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medmesh.SIZEOF_INT
SIZEOF_LONG = _medmesh.SIZEOF_LONG
STDC_HEADERS = _medmesh.STDC_HEADERS
VERSION = _medmesh.VERSION
HDF_VERSION_REF = _medmesh.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medmesh.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medmesh.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medmesh.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medmesh.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medmesh.H5F_LIBVER_18
MED_MAJOR_NUM = _medmesh.MED_MAJOR_NUM
MED_MINOR_NUM = _medmesh.MED_MINOR_NUM
MED_RELEASE_NUM = _medmesh.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medmesh.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medmesh.MED_4_LATEST_MINOR
MED_5_LATEST_MINOR = _medmesh.MED_5_LATEST_MINOR
MED_50_LATEST_RELEASE = _medmesh.MED_50_LATEST_RELEASE
MED_NUM_MAJEUR = _medmesh.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medmesh.MED_NUM_MINEUR
MED_NUM_RELEASE = _medmesh.MED_NUM_RELEASE
MED_VERSION_STR = _medmesh.MED_VERSION_STR
MED_MAX_PARA = _medmesh.MED_MAX_PARA
MED_COMMENT_SIZE = _medmesh.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medmesh.MED_IDENT_SIZE
MED_NAME_SIZE = _medmesh.MED_NAME_SIZE
MED_SNAME_SIZE = _medmesh.MED_SNAME_SIZE
MED_LNAME_SIZE = _medmesh.MED_LNAME_SIZE
MED_SNAME_BLANK = _medmesh.MED_SNAME_BLANK
MED_NAME_BLANK = _medmesh.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medmesh.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medmesh.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medmesh.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medmesh.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medmesh.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medmesh.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medmesh.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medmesh.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medmesh.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medmesh.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medmesh.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medmesh.MED_ACC_RDONLY
MED_ACC_RDWR = _medmesh.MED_ACC_RDWR
MED_ACC_RDEXT = _medmesh.MED_ACC_RDEXT
MED_ACC_CREAT = _medmesh.MED_ACC_CREAT
MED_ACC_UNDEF = _medmesh.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medmesh.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medmesh.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medmesh.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medmesh.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medmesh.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medmesh.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medmesh.MED_UNDEF_GRID_TYPE
MED_CELL = _medmesh.MED_CELL
MED_DESCENDING_FACE = _medmesh.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medmesh.MED_DESCENDING_EDGE
MED_NODE = _medmesh.MED_NODE
MED_NODE_ELEMENT = _medmesh.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medmesh.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medmesh.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medmesh.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medmesh.MED_N_ENTITY_TYPES
MED_COORDINATE = _medmesh.MED_COORDINATE
MED_CONNECTIVITY = _medmesh.MED_CONNECTIVITY
MED_NAME = _medmesh.MED_NAME
MED_NUMBER = _medmesh.MED_NUMBER
MED_FAMILY_NUMBER = _medmesh.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medmesh.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medmesh.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medmesh.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medmesh.MED_INDEX_FACE
MED_INDEX_NODE = _medmesh.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medmesh.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medmesh.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medmesh.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medmesh.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medmesh.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medmesh.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medmesh.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medmesh.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medmesh.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medmesh.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medmesh.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medmesh.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medmesh.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medmesh.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medmesh.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medmesh.MED_INTERNAL_UNDEF
MED_DOUBLE = _medmesh.MED_DOUBLE
MED_FLOAT64 = _medmesh.MED_FLOAT64
MED_FLOAT32 = _medmesh.MED_FLOAT32
MED_INT32 = _medmesh.MED_INT32
MED_INT64 = _medmesh.MED_INT64
MED_INT = _medmesh.MED_INT
MED_ATT_FLOAT64 = _medmesh.MED_ATT_FLOAT64
MED_ATT_INT = _medmesh.MED_ATT_INT
MED_ATT_NAME = _medmesh.MED_ATT_NAME
MED_ATT_UNDEF = _medmesh.MED_ATT_UNDEF
MED_MESH = _medmesh.MED_MESH
MED_FIELD = _medmesh.MED_FIELD
MED_LIBRARY = _medmesh.MED_LIBRARY
MED_FILE = _medmesh.MED_FILE
MED_MESH_SUPPORT = _medmesh.MED_MESH_SUPPORT
MED_ELSTRUCT = _medmesh.MED_ELSTRUCT
MED_FAMILY = _medmesh.MED_FAMILY
MED_EQUIVALENCE = _medmesh.MED_EQUIVALENCE
MED_GROUP = _medmesh.MED_GROUP
MED_JOINT = _medmesh.MED_JOINT
MED_LOCALIZATION = _medmesh.MED_LOCALIZATION
MED_PROFILE = _medmesh.MED_PROFILE
MED_FILTER = _medmesh.MED_FILTER
MED_INTERPOLATION = _medmesh.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medmesh.MED_NUMERICAL_DATA
MED_LINK = _medmesh.MED_LINK
MED_CLASS_UNDEF = _medmesh.MED_CLASS_UNDEF
MED_CLASS_ALL = _medmesh.MED_CLASS_ALL
MED_POINT1 = _medmesh.MED_POINT1
MED_SEG2 = _medmesh.MED_SEG2
MED_SEG3 = _medmesh.MED_SEG3
MED_SEG4 = _medmesh.MED_SEG4
MED_TRIA3 = _medmesh.MED_TRIA3
MED_QUAD4 = _medmesh.MED_QUAD4
MED_TRIA6 = _medmesh.MED_TRIA6
MED_TRIA7 = _medmesh.MED_TRIA7
MED_QUAD8 = _medmesh.MED_QUAD8
MED_QUAD9 = _medmesh.MED_QUAD9
MED_TETRA4 = _medmesh.MED_TETRA4
MED_PYRA5 = _medmesh.MED_PYRA5
MED_PENTA6 = _medmesh.MED_PENTA6
MED_HEXA8 = _medmesh.MED_HEXA8
MED_TETRA10 = _medmesh.MED_TETRA10
MED_OCTA12 = _medmesh.MED_OCTA12
MED_PYRA13 = _medmesh.MED_PYRA13
MED_PENTA15 = _medmesh.MED_PENTA15
MED_PENTA18 = _medmesh.MED_PENTA18
MED_HEXA20 = _medmesh.MED_HEXA20
MED_HEXA27 = _medmesh.MED_HEXA27
MED_POLYGON = _medmesh.MED_POLYGON
MED_POLYGON2 = _medmesh.MED_POLYGON2
MED_POLYHEDRON = _medmesh.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medmesh.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medmesh.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medmesh.MED_NONE
MED_NO_GEOTYPE = _medmesh.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medmesh.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medmesh.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medmesh.MED_ALL_GEOTYPE
MED_GEO_ALL = _medmesh.MED_GEO_ALL
MED_N_CELL_GEO = _medmesh.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medmesh.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medmesh.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medmesh.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medmesh.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medmesh.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medmesh.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medmesh.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medmesh.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medmesh.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medmesh.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medmesh.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medmesh.MED_NODAL
MED_DESCENDING = _medmesh.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medmesh.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medmesh.MED_NO_CMODE
MED_CARTESIAN = _medmesh.MED_CARTESIAN
MED_CYLINDRICAL = _medmesh.MED_CYLINDRICAL
MED_SPHERICAL = _medmesh.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medmesh.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medmesh.MED_FALSE
MED_TRUE = _medmesh.MED_TRUE
MED_GAUSS_ELNO = _medmesh.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medmesh.MED_IPOINT_ELNO
MED_NO_NAME = _medmesh.MED_NO_NAME
MED_NO_MESHNAME = _medmesh.MED_NO_MESHNAME
MED_NO_MESH = _medmesh.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medmesh.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medmesh.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medmesh.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medmesh.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medmesh.MED_NO_PROFILE
MED_NO_GROUP = _medmesh.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medmesh.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medmesh.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medmesh.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medmesh.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medmesh.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medmesh.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medmesh.MED_SORT_DTIT
MED_SORT_ITDT = _medmesh.MED_SORT_ITDT
MED_SORT_UNDEF = _medmesh.MED_SORT_UNDEF
MED_ALL_DT = _medmesh.MED_ALL_DT
MED_ALL_IT = _medmesh.MED_ALL_IT
MED_NO_DT = _medmesh.MED_NO_DT
MED_NO_IT = _medmesh.MED_NO_IT
MED_UNDEF_DT = _medmesh.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medmesh.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medmesh.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medmesh.med_filter_nspaces_get, _medmesh.med_filter_nspaces_set)
    memspace = property(_medmesh.med_filter_memspace_get, _medmesh.med_filter_memspace_set)
    diskspace = property(_medmesh.med_filter_diskspace_get, _medmesh.med_filter_diskspace_set)
    nentity = property(_medmesh.med_filter_nentity_get, _medmesh.med_filter_nentity_set)
    nvaluesperentity = property(_medmesh.med_filter_nvaluesperentity_get, _medmesh.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medmesh.med_filter_nconstituentpervalue_get, _medmesh.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medmesh.med_filter_constituentselect_get, _medmesh.med_filter_constituentselect_set)
    switchmode = property(_medmesh.med_filter_switchmode_get, _medmesh.med_filter_switchmode_set)
    filterarraysize = property(_medmesh.med_filter_filterarraysize_get, _medmesh.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medmesh.med_filter_filterarray23v30_get, _medmesh.med_filter_filterarray23v30_set)
    profilearraysize = property(_medmesh.med_filter_profilearraysize_get, _medmesh.med_filter_profilearraysize_set)
    storagemode = property(_medmesh.med_filter_storagemode_get, _medmesh.med_filter_storagemode_set)
    profilename = property(_medmesh.med_filter_profilename_get, _medmesh.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medmesh.med_filter_swiginit(self, _medmesh.new_med_filter())
    __swig_destroy__ = _medmesh.delete_med_filter

# Register med_filter in _medmesh:
_medmesh.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medmesh.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medmesh.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medmesh.med_file_version_majeur_get, _medmesh.med_file_version_majeur_set)
    mineur = property(_medmesh.med_file_version_mineur_get, _medmesh.med_file_version_mineur_set)
    release = property(_medmesh.med_file_version_release_get, _medmesh.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medmesh.med_file_version_swiginit(self, _medmesh.new_med_file_version())
    __swig_destroy__ = _medmesh.delete_med_file_version

# Register med_file_version in _medmesh:
_medmesh.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medmesh.med_memfile_app_image_ptr_get, _medmesh.med_memfile_app_image_ptr_set)
    app_image_size = property(_medmesh.med_memfile_app_image_size_get, _medmesh.med_memfile_app_image_size_set)
    ref_count = property(_medmesh.med_memfile_ref_count_get, _medmesh.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medmesh.med_memfile_fapl_image_ptr_get, _medmesh.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medmesh.med_memfile_fapl_image_size_get, _medmesh.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medmesh.med_memfile_fapl_ref_count_get, _medmesh.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medmesh.med_memfile_vfd_image_ptr_get, _medmesh.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medmesh.med_memfile_vfd_image_size_get, _medmesh.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medmesh.med_memfile_vfd_ref_count_get, _medmesh.med_memfile_vfd_ref_count_set)
    flags = property(_medmesh.med_memfile_flags_get, _medmesh.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medmesh.med_memfile_swiginit(self, _medmesh.new_med_memfile())
    __swig_destroy__ = _medmesh.delete_med_memfile

# Register med_memfile in _medmesh:
_medmesh.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medmesh.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medmesh.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medmesh.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medmesh.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medmesh.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medmesh.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medmesh.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medmesh.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medmesh.MED_PARTICLE_NAME
MED_BALL_NAME = _medmesh.MED_BALL_NAME
MED_BEAM_NAME = _medmesh.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medmesh.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medmesh.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medmesh.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medmesh.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medmesh.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medmesh.MEDBOOL___bool__(self)

    def __len__(self):
        return _medmesh.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medmesh.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medmesh.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medmesh.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medmesh.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medmesh.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medmesh.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medmesh.MEDBOOL_pop(self)

    def append(self, x):
        return _medmesh.MEDBOOL_append(self, x)

    def empty(self):
        return _medmesh.MEDBOOL_empty(self)

    def size(self):
        return _medmesh.MEDBOOL_size(self)

    def swap(self, v):
        return _medmesh.MEDBOOL_swap(self, v)

    def begin(self):
        return _medmesh.MEDBOOL_begin(self)

    def end(self):
        return _medmesh.MEDBOOL_end(self)

    def rbegin(self):
        return _medmesh.MEDBOOL_rbegin(self)

    def rend(self):
        return _medmesh.MEDBOOL_rend(self)

    def clear(self):
        return _medmesh.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medmesh.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medmesh.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medmesh.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medmesh.MEDBOOL_swiginit(self, _medmesh.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medmesh.MEDBOOL_push_back(self, x)

    def front(self):
        return _medmesh.MEDBOOL_front(self)

    def back(self):
        return _medmesh.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medmesh.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medmesh.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medmesh.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medmesh.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medmesh.MEDBOOL_capacity(self)
    __swig_destroy__ = _medmesh.delete_MEDBOOL

# Register MEDBOOL in _medmesh:
_medmesh.MEDBOOL_swigregister(MEDBOOL)
cvar = _medmesh.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medmesh.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medmesh.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medmesh.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medmesh.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medmesh.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medmesh.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medmesh.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medmesh.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medmesh.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medmesh.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medmesh.MEDFLOAT_pop(self)

    def append(self, x):
        return _medmesh.MEDFLOAT_append(self, x)

    def empty(self):
        return _medmesh.MEDFLOAT_empty(self)

    def size(self):
        return _medmesh.MEDFLOAT_size(self)

    def swap(self, v):
        return _medmesh.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medmesh.MEDFLOAT_begin(self)

    def end(self):
        return _medmesh.MEDFLOAT_end(self)

    def rbegin(self):
        return _medmesh.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medmesh.MEDFLOAT_rend(self)

    def clear(self):
        return _medmesh.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medmesh.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medmesh.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medmesh.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medmesh.MEDFLOAT_swiginit(self, _medmesh.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medmesh.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medmesh.MEDFLOAT_front(self)

    def back(self):
        return _medmesh.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medmesh.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medmesh.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medmesh.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medmesh.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medmesh.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medmesh.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medmesh.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medmesh.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medmesh.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medmesh.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medmesh.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medmesh.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medmesh.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medmesh.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medmesh.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medmesh.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medmesh.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDFLOAT

# Register MEDFLOAT in _medmesh:
_medmesh.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medmesh.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medmesh.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medmesh.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medmesh.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medmesh.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medmesh.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medmesh.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medmesh.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medmesh.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medmesh.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medmesh.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medmesh.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medmesh.MEDFLOAT32_empty(self)

    def size(self):
        return _medmesh.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medmesh.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medmesh.MEDFLOAT32_begin(self)

    def end(self):
        return _medmesh.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medmesh.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medmesh.MEDFLOAT32_rend(self)

    def clear(self):
        return _medmesh.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medmesh.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medmesh.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medmesh.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medmesh.MEDFLOAT32_swiginit(self, _medmesh.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medmesh.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medmesh.MEDFLOAT32_front(self)

    def back(self):
        return _medmesh.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medmesh.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medmesh.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medmesh.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medmesh.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medmesh.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medmesh.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medmesh.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medmesh.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medmesh.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medmesh.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medmesh.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medmesh.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medmesh.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medmesh.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medmesh.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medmesh.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medmesh.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medmesh:
_medmesh.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medmesh.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medmesh.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medmesh.MEDINT___bool__(self)

    def __len__(self):
        return _medmesh.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medmesh.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medmesh.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medmesh.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medmesh.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medmesh.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medmesh.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medmesh.MEDINT_pop(self)

    def append(self, x):
        return _medmesh.MEDINT_append(self, x)

    def empty(self):
        return _medmesh.MEDINT_empty(self)

    def size(self):
        return _medmesh.MEDINT_size(self)

    def swap(self, v):
        return _medmesh.MEDINT_swap(self, v)

    def begin(self):
        return _medmesh.MEDINT_begin(self)

    def end(self):
        return _medmesh.MEDINT_end(self)

    def rbegin(self):
        return _medmesh.MEDINT_rbegin(self)

    def rend(self):
        return _medmesh.MEDINT_rend(self)

    def clear(self):
        return _medmesh.MEDINT_clear(self)

    def get_allocator(self):
        return _medmesh.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medmesh.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medmesh.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medmesh.MEDINT_swiginit(self, _medmesh.new_MEDINT(*args))

    def push_back(self, x):
        return _medmesh.MEDINT_push_back(self, x)

    def front(self):
        return _medmesh.MEDINT_front(self)

    def back(self):
        return _medmesh.MEDINT_back(self)

    def assign(self, n, x):
        return _medmesh.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medmesh.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medmesh.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medmesh.MEDINT_reserve(self, n)

    def capacity(self):
        return _medmesh.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medmesh.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medmesh.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medmesh.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medmesh.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medmesh.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medmesh.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medmesh.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medmesh.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medmesh.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medmesh.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medmesh.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medmesh.MEDINT___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDINT

# Register MEDINT in _medmesh:
_medmesh.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medmesh.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medmesh.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medmesh.MEDCHAR___bool__(self)

    def __len__(self):
        return _medmesh.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medmesh.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medmesh.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medmesh.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medmesh.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medmesh.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medmesh.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medmesh.MEDCHAR_pop(self)

    def append(self, x):
        return _medmesh.MEDCHAR_append(self, x)

    def empty(self):
        return _medmesh.MEDCHAR_empty(self)

    def size(self):
        return _medmesh.MEDCHAR_size(self)

    def swap(self, v):
        return _medmesh.MEDCHAR_swap(self, v)

    def begin(self):
        return _medmesh.MEDCHAR_begin(self)

    def end(self):
        return _medmesh.MEDCHAR_end(self)

    def rbegin(self):
        return _medmesh.MEDCHAR_rbegin(self)

    def rend(self):
        return _medmesh.MEDCHAR_rend(self)

    def clear(self):
        return _medmesh.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medmesh.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medmesh.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medmesh.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medmesh.MEDCHAR_swiginit(self, _medmesh.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medmesh.MEDCHAR_push_back(self, x)

    def front(self):
        return _medmesh.MEDCHAR_front(self)

    def back(self):
        return _medmesh.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medmesh.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medmesh.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medmesh.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medmesh.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medmesh.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medmesh.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medmesh.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medmesh.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medmesh.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medmesh.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medmesh.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medmesh.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medmesh.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medmesh.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medmesh.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medmesh.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medmesh.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDCHAR

# Register MEDCHAR in _medmesh:
_medmesh.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDmeshCr(fid, meshname, spacedim, meshdim, meshtype, description, dtunit, sortingtype, axistype, axisname, axisunit):
    r"""
    MEDmeshCr(fid, meshname, spacedim, meshdim, meshtype, description, dtunit, sortingtype, axistype, axisname, axisunit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    spacedim: med_int const
    meshdim: med_int const
    meshtype: enum med_mesh_type const
    description: char const *const
    dtunit: char const *const
    sortingtype: enum med_sorting_type const
    axistype: enum med_axis_type const
    axisname: char const *const
    axisunit: char const *const

    Essai d Ajout a La Documentation Automatique
    """
    return _medmesh.MEDmeshCr(fid, meshname, spacedim, meshdim, meshtype, description, dtunit, sortingtype, axistype, axisname, axisunit)

def MEDmeshInfoByName(fid, meshname):
    r"""
    MEDmeshInfoByName(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshInfoByName(fid, meshname)

def MEDmeshInfo(fid, meshit):
    r"""
    MEDmeshInfo(fid, meshit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshit: int const

    """
    return _medmesh.MEDmeshInfo(fid, meshit)

def MEDnMesh(fid):
    r"""
    MEDnMesh(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medmesh.MEDnMesh(fid)

def MEDmeshnAxis(fid, meshit):
    r"""
    MEDmeshnAxis(fid, meshit) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshit: int const

    """
    return _medmesh.MEDmeshnAxis(fid, meshit)

def MEDmeshnAxisByName(fid, meshname):
    r"""
    MEDmeshnAxisByName(fid, meshname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshnAxisByName(fid, meshname)

def MEDmeshGridTypeWr(fid, meshname, gridtype):
    r"""
    MEDmeshGridTypeWr(fid, meshname, gridtype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    gridtype: enum med_grid_type const

    """
    return _medmesh.MEDmeshGridTypeWr(fid, meshname, gridtype)

def MEDmeshGridTypeRd(fid, meshname):
    r"""
    MEDmeshGridTypeRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshGridTypeRd(fid, meshname)

def MEDmeshGridIndexCoordinateWr(fid, meshname, numdt, numit, dt, axis, indexsize, gridindex):
    r"""
    MEDmeshGridIndexCoordinateWr(fid, meshname, numdt, numit, dt, axis, indexsize, gridindex) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    axis: med_int const
    indexsize: med_int const
    gridindex: med_float const *const

    """
    return _medmesh.MEDmeshGridIndexCoordinateWr(fid, meshname, numdt, numit, dt, axis, indexsize, gridindex)

def MEDmeshGridIndexCoordinateRd(fid, meshname, numdt, numit, axis, gridindex):
    r"""
    MEDmeshGridIndexCoordinateRd(fid, meshname, numdt, numit, axis, gridindex) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    axis: med_int const
    gridindex: med_float *const

    """
    return _medmesh.MEDmeshGridIndexCoordinateRd(fid, meshname, numdt, numit, axis, gridindex)

def MEDmeshGridStructWr(fid, meshname, numdt, numit, dt, gridstruct):
    r"""
    MEDmeshGridStructWr(fid, meshname, numdt, numit, dt, gridstruct) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    gridstruct: med_int const *const

    """
    return _medmesh.MEDmeshGridStructWr(fid, meshname, numdt, numit, dt, gridstruct)

def MEDmeshGridStructRd(fid, meshname, numdt, numit, gridstruct):
    r"""
    MEDmeshGridStructRd(fid, meshname, numdt, numit, gridstruct) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    gridstruct: med_int *const

    """
    return _medmesh.MEDmeshGridStructRd(fid, meshname, numdt, numit, gridstruct)

def MEDmeshUniversalNameWr(fid, meshname):
    r"""
    MEDmeshUniversalNameWr(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshUniversalNameWr(fid, meshname)

def MEDmeshUniversalNameRd(fid, meshname):
    r"""
    MEDmeshUniversalNameRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshUniversalNameRd(fid, meshname)

def MEDmeshComputationStepCr(fid, meshname, numdt1, numit1, numdt2, numit2, dt2):
    r"""
    MEDmeshComputationStepCr(fid, meshname, numdt1, numit1, numdt2, numit2, dt2) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt1: med_int const
    numit1: med_int const
    numdt2: med_int const
    numit2: med_int const
    dt2: med_float const

    """
    return _medmesh.MEDmeshComputationStepCr(fid, meshname, numdt1, numit1, numdt2, numit2, dt2)

def MEDmeshAttributeRd(fid, meshname):
    r"""
    MEDmeshAttributeRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshAttributeRd(fid, meshname)

def MEDmeshAttributeWr(fid, meshname, isolatednodes, verticesnodes, cellmaxnodes):
    r"""
    MEDmeshAttributeWr(fid, meshname, isolatednodes, verticesnodes, cellmaxnodes) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    isolatednodes: med_int const
    verticesnodes: med_int const
    cellmaxnodes: med_int const

    """
    return _medmesh.MEDmeshAttributeWr(fid, meshname, isolatednodes, verticesnodes, cellmaxnodes)

def MEDmeshComputationStepDtRd(fid, meshname, numdt, umit):
    r"""
    MEDmeshComputationStepDtRd(fid, meshname, numdt, umit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    umit: med_int const

    """
    return _medmesh.MEDmeshComputationStepDtRd(fid, meshname, numdt, umit)

def MEDmeshComputationStepInfo(fid, meshname, csit):
    r"""
    MEDmeshComputationStepInfo(fid, meshname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    csit: int const

    """
    return _medmesh.MEDmeshComputationStepInfo(fid, meshname, csit)

def MEDmeshSortingTypeRd(fid, meshname):
    r"""
    MEDmeshSortingTypeRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshSortingTypeRd(fid, meshname)

def MEDmeshNodeCoordinateAdvancedWr(fid, meshname, numdt, numit, dt, filter, value):
    r"""
    MEDmeshNodeCoordinateAdvancedWr(fid, meshname, numdt, numit, dt, filter, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    filter: med_filter const *const
    value: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateAdvancedWr(fid, meshname, numdt, numit, dt, filter, value)

def MEDmeshNodeCoordinateWithProfileWr(fid, meshname, numdt, numit, dt, storagemode, profilename, switchmode, dimselect, nentity, coordinates):
    r"""
    MEDmeshNodeCoordinateWithProfileWr(fid, meshname, numdt, numit, dt, storagemode, profilename, switchmode, dimselect, nentity, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    nentity: med_int const
    coordinates: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateWithProfileWr(fid, meshname, numdt, numit, dt, storagemode, profilename, switchmode, dimselect, nentity, coordinates)

def MEDmeshNodeCoordinateWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinates):
    r"""
    MEDmeshNodeCoordinateWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    coordinates: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinates)

def MEDmeshNodeCoordinateTrsfWr(fid, meshname, numdt, numit, dt, coordinatetrsf):
    r"""
    MEDmeshNodeCoordinateTrsfWr(fid, meshname, numdt, numit, dt, coordinatetrsf) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    coordinatetrsf: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateTrsfWr(fid, meshname, numdt, numit, dt, coordinatetrsf)

def MEDmeshNodeCoordinateTrsfRd(fid, meshname, numdt, numit, coordinatetrsf):
    r"""
    MEDmeshNodeCoordinateTrsfRd(fid, meshname, numdt, numit, coordinatetrsf) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    coordinatetrsf: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateTrsfRd(fid, meshname, numdt, numit, coordinatetrsf)

def MEDmeshElementConnectivityWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity):
    r"""
    MEDmeshElementConnectivityWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshElementConnectivityWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity)

def MEDmeshElementConnectivityAdvancedWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, filter, connectivity):
    r"""
    MEDmeshElementConnectivityAdvancedWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, filter, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    filter: med_filter const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshElementConnectivityAdvancedWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, filter, connectivity)

def MEDmeshElementConnectivityWithProfileWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity):
    r"""
    MEDmeshElementConnectivityWithProfileWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    nentity: med_int const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshElementConnectivityWithProfileWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity)

def MEDmeshNodeCoordinateAdvancedRd(fid, meshname, numdt, numit, filter, value):
    r"""
    MEDmeshNodeCoordinateAdvancedRd(fid, meshname, numdt, numit, filter, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    filter: med_filter const *const
    value: med_float *const

    """
    return _medmesh.MEDmeshNodeCoordinateAdvancedRd(fid, meshname, numdt, numit, filter, value)

def MEDmeshNodeCoordinateWithProfileRd(fid, meshname, numdt, numit, storagemode, profilename, switchmode, dimselect, coordinates):
    r"""
    MEDmeshNodeCoordinateWithProfileRd(fid, meshname, numdt, numit, storagemode, profilename, switchmode, dimselect, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    coordinates: med_float *const

    """
    return _medmesh.MEDmeshNodeCoordinateWithProfileRd(fid, meshname, numdt, numit, storagemode, profilename, switchmode, dimselect, coordinates)

def MEDmeshNodeCoordinateRd(fid, meshname, numdt, numit, switchmode, coordinates):
    r"""
    MEDmeshNodeCoordinateRd(fid, meshname, numdt, numit, switchmode, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    switchmode: enum med_switch_mode const
    coordinates: med_float *const

    """
    return _medmesh.MEDmeshNodeCoordinateRd(fid, meshname, numdt, numit, switchmode, coordinates)

def MEDmeshElementConnectivityRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity):
    r"""
    MEDmeshElementConnectivityRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshElementConnectivityRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity)

def MEDmeshElementConnectivityAdvancedRd(fid, meshname, numdt, numit, entitype, geotype, cmode, filter, connectivity):
    r"""
    MEDmeshElementConnectivityAdvancedRd(fid, meshname, numdt, numit, entitype, geotype, cmode, filter, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    filter: med_filter const *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshElementConnectivityAdvancedRd(fid, meshname, numdt, numit, entitype, geotype, cmode, filter, connectivity)

def MEDmeshElementConnectivityWithProfileRd(fid, meshname, numdt, numit, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity):
    r"""
    MEDmeshElementConnectivityWithProfileRd(fid, meshname, numdt, numit, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    nentity: med_int const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshElementConnectivityWithProfileRd(fid, meshname, numdt, numit, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity)

def MEDmeshnEntity(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode):
    r"""
    MEDmeshnEntity(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    datatype: enum med_data_type const
    cmode: enum med_connectivity_mode const

    """
    return _medmesh.MEDmeshnEntity(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode)

def MEDmeshnEntityWithProfile(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode, storagemode):
    r"""
    MEDmeshnEntityWithProfile(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode, storagemode) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    datatype: enum med_data_type const
    cmode: enum med_connectivity_mode const
    storagemode: enum med_storage_mode const

    """
    return _medmesh.MEDmeshnEntityWithProfile(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode, storagemode)

def MEDmeshEntityInfo(fid, meshname, numdt, numit, entitype, geotypeit):
    r"""
    MEDmeshEntityInfo(fid, meshname, numdt, numit, entitype, geotypeit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotypeit: int const

    """
    return _medmesh.MEDmeshEntityInfo(fid, meshname, numdt, numit, entitype, geotypeit)

def MEDmeshEntityNameWr(fid, meshname, numdt, numit, entitype, geotype, nentity, name):
    r"""
    MEDmeshEntityNameWr(fid, meshname, numdt, numit, entitype, geotype, nentity, name) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    name: char const *const

    """
    return _medmesh.MEDmeshEntityNameWr(fid, meshname, numdt, numit, entitype, geotype, nentity, name)

def MEDmeshEntityNameRd(fid, meshname, numdt, numit, entitype, geotype, name):
    r"""
    MEDmeshEntityNameRd(fid, meshname, numdt, numit, entitype, geotype, name) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    name: char *const

    """
    return _medmesh.MEDmeshEntityNameRd(fid, meshname, numdt, numit, entitype, geotype, name)

def MEDmeshEntityNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number):
    r"""
    MEDmeshEntityNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    number: med_int const *const

    """
    return _medmesh.MEDmeshEntityNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number)

def MEDmeshEntityNumberRd(fid, meshname, numdt, numit, entitype, geotype, number):
    r"""
    MEDmeshEntityNumberRd(fid, meshname, numdt, numit, entitype, geotype, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    number: med_int *const

    """
    return _medmesh.MEDmeshEntityNumberRd(fid, meshname, numdt, numit, entitype, geotype, number)

def MEDmeshEntityFamilyNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number):
    r"""
    MEDmeshEntityFamilyNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    number: med_int const *const

    """
    return _medmesh.MEDmeshEntityFamilyNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number)

def MEDmeshEntityFamilyNumberRd(fid, meshname, numdt, numit, entitype, geotype, number):
    r"""
    MEDmeshEntityFamilyNumberRd(fid, meshname, numdt, numit, entitype, geotype, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    number: med_int *const

    """
    return _medmesh.MEDmeshEntityFamilyNumberRd(fid, meshname, numdt, numit, entitype, geotype, number)

def MEDmeshEntityAttributeAdvancedRd(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval):
    r"""
    MEDmeshEntityAttributeAdvancedRd(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    datatype: enum med_data_type const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    filter: med_filter const *const
    attval: void *const

    """
    return _medmesh.MEDmeshEntityAttributeAdvancedRd(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval)

def MEDmeshEntityAttributeAdvancedWr(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval):
    r"""
    MEDmeshEntityAttributeAdvancedWr(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    datatype: enum med_data_type const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    filter: med_filter const *const
    attval: void const *const

    """
    return _medmesh.MEDmeshEntityAttributeAdvancedWr(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval)

def MEDmeshPolygonWr(fid, meshname, numdt, numit, dt, entitype, cmode, indexsize, polyindex, connectivity):
    r"""
    MEDmeshPolygonWr(fid, meshname, numdt, numit, dt, entitype, cmode, indexsize, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    indexsize: med_int const
    polyindex: med_int const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshPolygonWr(fid, meshname, numdt, numit, dt, entitype, cmode, indexsize, polyindex, connectivity)

def MEDmeshPolygon2Wr(fid, meshname, numdt, numit, dt, entitype, polytype, cmode, indexsize, polyindex, connectivity):
    r"""
    MEDmeshPolygon2Wr(fid, meshname, numdt, numit, dt, entitype, polytype, cmode, indexsize, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    polytype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    indexsize: med_int const
    polyindex: med_int const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshPolygon2Wr(fid, meshname, numdt, numit, dt, entitype, polytype, cmode, indexsize, polyindex, connectivity)

def MEDmeshPolygonRd(fid, meshname, numdt, numit, entitype, cmode, polyindex, connectivity):
    r"""
    MEDmeshPolygonRd(fid, meshname, numdt, numit, entitype, cmode, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    polyindex: med_int *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshPolygonRd(fid, meshname, numdt, numit, entitype, cmode, polyindex, connectivity)

def MEDmeshPolygon2Rd(fid, meshname, numdt, numit, entitype, polytype, cmode, polyindex, connectivity):
    r"""
    MEDmeshPolygon2Rd(fid, meshname, numdt, numit, entitype, polytype, cmode, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    polytype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    polyindex: med_int *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshPolygon2Rd(fid, meshname, numdt, numit, entitype, polytype, cmode, polyindex, connectivity)

def MEDmeshPolyhedronRd(fid, meshname, numdt, numit, entitype, cmode, faceindex, nodeindex, connectivity):
    r"""
    MEDmeshPolyhedronRd(fid, meshname, numdt, numit, entitype, cmode, faceindex, nodeindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    faceindex: med_int *const
    nodeindex: med_int *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshPolyhedronRd(fid, meshname, numdt, numit, entitype, cmode, faceindex, nodeindex, connectivity)

def MEDmeshPolyhedronWr(fid, meshname, numdt, numit, dt, entitype, cmode, faceindexsize, faceindex, nodeindexsize, nodeindex, connectivity):
    r"""
    MEDmeshPolyhedronWr(fid, meshname, numdt, numit, dt, entitype, cmode, faceindexsize, faceindex, nodeindexsize, nodeindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    faceindexsize: med_int const
    faceindex: med_int const *const
    nodeindexsize: med_int const
    nodeindex: med_int const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshPolyhedronWr(fid, meshname, numdt, numit, dt, entitype, cmode, faceindexsize, faceindex, nodeindexsize, nodeindex, connectivity)

def MEDmeshGeotypeName(fid, geotype):
    r"""
    MEDmeshGeotypeName(fid, geotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    geotype: med_geometry_type const

    """
    return _medmesh.MEDmeshGeotypeName(fid, geotype)

def MEDmeshGeotypeParameter(fid, geotype):
    r"""
    MEDmeshGeotypeParameter(fid, geotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    geotype: med_geometry_type const

    """
    return _medmesh.MEDmeshGeotypeParameter(fid, geotype)

def MEDmeshGlobalNumberWr(fid, meshname, numdt, numit, entitytype, geotype, nentity, number):
    r"""
    MEDmeshGlobalNumberWr(fid, meshname, numdt, numit, entitytype, geotype, nentity, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitytype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    number: med_int const *const

    """
    return _medmesh.MEDmeshGlobalNumberWr(fid, meshname, numdt, numit, entitytype, geotype, nentity, number)

def MEDmeshGlobalNumberRd(fid, meshname, numdt, numit, entitytype, geotype, number):
    r"""
    MEDmeshGlobalNumberRd(fid, meshname, numdt, numit, entitytype, geotype, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitytype: enum med_entity_type const
    geotype: med_geometry_type const
    number: med_int *const

    """
    return _medmesh.MEDmeshGlobalNumberRd(fid, meshname, numdt, numit, entitytype, geotype, number)

def MEDmeshNodeWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinate, withnodename, nodename, withnodenumber, nodenumber, withfamnumber, famnumber):
    r"""
    MEDmeshNodeWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinate, withnodename, nodename, withnodenumber, nodenumber, withfamnumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    coordinate: med_float const *const
    withnodename: enum med_bool const
    nodename: char const *const
    withnodenumber: enum med_bool const
    nodenumber: med_int const *const
    withfamnumber: enum med_bool const
    famnumber: med_int const *const

    """
    return _medmesh.MEDmeshNodeWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinate, withnodename, nodename, withnodenumber, nodenumber, withfamnumber, famnumber)

def MEDmeshNodeRd(fid, meshname, numdt, numit, switchmode, coordinate, nodename, nodenumber, famnumber):
    r"""
    MEDmeshNodeRd(fid, meshname, numdt, numit, switchmode, coordinate, nodename, nodenumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    switchmode: enum med_switch_mode const
    coordinate: med_float *const
    nodename: char *const
    nodenumber: med_int *const
    famnumber: med_int *const

    """
    return _medmesh.MEDmeshNodeRd(fid, meshname, numdt, numit, switchmode, coordinate, nodename, nodenumber, famnumber)

def MEDmeshElementWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity, withelementname, elementname, withelementnumber, elementnumber, withfamnumber, famnumber):
    r"""
    MEDmeshElementWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity, withelementname, elementname, withelementnumber, elementnumber, withfamnumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    connectivity: med_int const *const
    withelementname: enum med_bool const
    elementname: char const *const
    withelementnumber: enum med_bool const
    elementnumber: med_int const *const
    withfamnumber: enum med_bool const
    famnumber: med_int const *const

    """
    return _medmesh.MEDmeshElementWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity, withelementname, elementname, withelementnumber, elementnumber, withfamnumber, famnumber)

def MEDmeshElementRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity, elementname, elementnumber, famnumber):
    r"""
    MEDmeshElementRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity, elementname, elementnumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    connectivity: med_int *const
    elementname: char *const
    elementnumber: med_int *const
    famnumber: med_int *const

    """
    return _medmesh.MEDmeshElementRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity, elementname, elementnumber, famnumber)

def MEDsupportMeshCr(fid, supportmeshname, spacedim, meshdim, description, axistype, axisname, axisunit):
    r"""
    MEDsupportMeshCr(fid, supportmeshname, spacedim, meshdim, description, axistype, axisname, axisunit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    supportmeshname: char const *const
    spacedim: med_int const
    meshdim: med_int const
    description: char const *const
    axistype: enum med_axis_type const
    axisname: char const *const
    axisunit: char const *const

    """
    return _medmesh.MEDsupportMeshCr(fid, supportmeshname, spacedim, meshdim, description, axistype, axisname, axisunit)

def MEDsupportMeshInfoByName(fid, supportmeshname):
    r"""
    MEDsupportMeshInfoByName(fid, supportmeshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    supportmeshname: char const *const

    """
    return _medmesh.MEDsupportMeshInfoByName(fid, supportmeshname)

def MEDsupportMeshInfo(fid, meshit):
    r"""
    MEDsupportMeshInfo(fid, meshit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshit: int const

    """
    return _medmesh.MEDsupportMeshInfo(fid, meshit)

def MEDnSupportMesh(fid):
    r"""
    MEDnSupportMesh(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medmesh.MEDnSupportMesh(fid)

def MEDsupportMeshnAxis(fid, meshit):
    r"""
    MEDsupportMeshnAxis(fid, meshit) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshit: int const

    """
    return _medmesh.MEDsupportMeshnAxis(fid, meshit)

def MEDsupportMeshnAxisByName(fid, meshname):
    r"""
    MEDsupportMeshnAxisByName(fid, meshname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDsupportMeshnAxisByName(fid, meshname)

